==> haskell-configfile-1.1.4-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ConfigFile
version:              1.1.4
visibility:           public
id:                   ConfigFile-1.1.4-D9nQidmhRLZ2k5C4Su5Mr8
key:                  ConfigFile-1.1.4-D9nQidmhRLZ2k5C4Su5Mr8
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2014 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Stable
homepage:             http://software.complete.org/configfile
synopsis:             Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.

    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.

    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.

category:             Parsing
abi:                  e3185e93eea523c3f8537095732feb16
exposed:              True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types

hidden-modules:       Data.ConfigFile.Lexer
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ConfigFile-1.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configfile
hs-libraries:         HSConfigFile-1.1.4-D9nQidmhRLZ2k5C4Su5Mr8
depends:
    MissingH-1.5.0.1-5RetAfNxxDI6NQ15mwBniJ base-4.15.1.0
    containers-0.6.4.1 mtl-2.2.2 parsec-3.1.14.0

haddock-interfaces:   /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html:         /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ConfigFile
version:              1.1.4
visibility:           public
id:                   ConfigFile-1.1.4-7of48rK1XB4Ef8TpFryXl2
key:                  ConfigFile-1.1.4-7of48rK1XB4Ef8TpFryXl2
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2014 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Stable
homepage:             http://software.complete.org/configfile
synopsis:             Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.

    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.

    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.

category:             Parsing
abi:                  20103104f362127181bdde4a8bda246d
exposed:              True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types

hidden-modules:       Data.ConfigFile.Lexer
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ConfigFile-1.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configfile
hs-libraries:         HSConfigFile-1.1.4-7of48rK1XB4Ef8TpFryXl2
depends:
    MissingH-1.5.0.1-KsuKgnRJcCALL2pmMFGmqd base-4.15.1.0
    containers-0.6.4.1 mtl-2.2.2 parsec-3.1.14.0

haddock-interfaces:   /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html:         /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
